summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2017-09-14 12:47:45 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2017-09-14 12:48:53 -0500
commit1c98b8588624c6be62186e5c7ad138f922832413 (patch)
tree45c0b917c78e8a57c2c244285bf00b97b6806290 /png.h
parent4de130c255b37879b653080bdda7b4694ec120ce (diff)
downloadlibpng-1c98b8588624c6be62186e5c7ad138f922832413.tar.gz
[libpng16] Bump version to 1.6.33beta04
Diffstat (limited to 'png.h')
-rw-r--r--png.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/png.h b/png.h
index 552fb4de8..ba31c138a 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.33beta03, September 14, 2017
*
* Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.33beta03, September 14, 2017:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
*/
@@ -25,7 +25,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000 through 1.6.33beta03, September 14, 2017 are
* Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
* disclaimer and license as libpng-1.0.6 with the following individuals
@@ -247,7 +247,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.33beta03 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -309,8 +309,8 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.33beta03"
-#define PNG_HEADER_VERSION_STRING " libpng version 1.6.33beta03 - September 14, 2017\n"
+#define PNG_LIBPNG_VER_STRING "1.6.33beta04"
+#define PNG_HEADER_VERSION_STRING " libpng version 1.6.33beta04 - September 14, 2017\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -324,7 +324,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 03
+#define PNG_LIBPNG_VER_BUILD 04
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -459,7 +459,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_33beta03;
+typedef char* png_libpng_version_1_6_33beta04;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.33beta03, September 14, 2017
+ * libpng version 1.6.33beta04, September 14, 2017
*
* Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.33beta03, September 14, 2017:
+ * libpng versions 0.97, January 1998, through 1.6.33beta04, September 14, 2017:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
@@ -25,7 +25,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000 through 1.6.33beta03, September 14, 2017 are
+ * libpng versions 1.0.7, July 1, 2000 through 1.6.33beta04, September 14, 2017 are
* Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
@@ -247,7 +247,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.33beta03 are Y2K compliant. It is my belief that
+ * upward through 1.6.33beta04 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*